Module: Google::Cloud::GSuiteAddOns

Defined in:
lib/google/cloud/gsuite_add_ons.rb,
lib/google/cloud/gsuite_add_ons/version.rb

Constant Summary collapse

VERSION =
"1.3.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.gsuite_add_ons| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-gsuite_add_ons library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



174
175
176
177
178
# File 'lib/google/cloud/gsuite_add_ons.rb', line 174

def self.configure
  yield ::Google::Cloud.configure.gsuite_add_ons if block_given?

  ::Google::Cloud.configure.gsuite_add_ons
end

.gsuite_add_ons(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for GSuiteAddOns.

By default, this returns an instance of Google::Cloud::GSuiteAddOns::V1::GSuiteAddOns::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the GSuiteAddOns service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the GSuiteAddOns service. You can determine whether the method will succeed by calling gsuite_add_ons_available?.

About GSuiteAddOns

A service for managing Google Workspace add-ons deployments.

A Google Workspace add-on is a third-party embedded component that can be installed in Google Workspace Applications like Gmail, Calendar, Drive, and the Google Docs, Sheets, and Slides editors. Google Workspace add-ons can display UI cards, receive contextual information from the host application, and perform actions in the host application (See: https://developers.google.com/gsuite/add-ons/overview for more information).

A Google Workspace add-on deployment resource specifies metadata about the add-on, including a specification of the entry points in the host application that trigger add-on executions (see: https://developers.google.com/gsuite/add-ons/concepts/gsuite-manifests). Add-on deployments defined via the Google Workspace add-ons API define their entrypoints using HTTPS URLs (See: https://developers.google.com/gsuite/add-ons/guides/alternate-runtimes),

A Google Workspace add-on deployment can be installed in developer mode, which allows an add-on developer to test the experience an end-user would see when installing and running the add-on in their G Suite applications. When running in developer mode, more detailed error messages are exposed in the add-on UI to aid in debugging.

A Google Workspace add-on deployment can be published to Google Workspace Marketplace, which allows other Google Workspace users to discover and install the add-on. See: https://developers.google.com/gsuite/add-ons/how-tos/publish-add-on-overview for details.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/google/cloud/gsuite_add_ons.rb', line 102

def self.gsuite_add_ons version: :v1, transport: :grpc, &block
  require "google/cloud/gsuite_add_ons/#{version.to_s.downcase}"

  package_name = Google::Cloud::GSuiteAddOns
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::GSuiteAddOns.const_get(package_name).const_get(:GSuiteAddOns)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.gsuite_add_ons_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the GSuiteAddOns service is supported by the current client. If true, you can retrieve a client object by calling gsuite_add_ons. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the GSuiteAddOns service, or if the versioned client gem needs an update to support the GSuiteAddOns service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/google/cloud/gsuite_add_ons.rb', line 126

def self.gsuite_add_ons_available? version: :v1, transport: :grpc
  require "google/cloud/gsuite_add_ons/#{version.to_s.downcase}"
  package_name = Google::Cloud::GSuiteAddOns
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::GSuiteAddOns.const_get package_name
  return false unless service_module.const_defined? :GSuiteAddOns
  service_module = service_module.const_get :GSuiteAddOns
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end